@@ -11,7 +11,7 @@
 clear_stash <- function() {
     message("Clearing stash.")
     file.remove(c(
-        list.files(.stash_dir, full.names = TRUE, pattern = "rds$"),
+        list.files(.stash_dir, full.names = TRUE, pattern = "qs$"),
         list.files(.stash_dir, full.names = TRUE, pattern = "hash$")
     ))
     invisible(NULL)
