@@ -5,14 +5,14 @@ test_that("the stash gets cleared", {
         on.exit(unlink(target_dir))
     }
 
-    rds_file <- file.path(target_dir, "stash1.rds")
+    qs_file <- file.path(target_dir, "stash1.qs")
     hash_file <- file.path(target_dir, "stash1.hash")
     other_file <- file.path(target_dir, "other_file.txt")
 
-    file.create(c(rds_file, hash_file, other_file))
+    file.create(c(qs_file, hash_file, other_file))
 
-    expect_true(all(file.exists(c(rds_file, hash_file, other_file))))
+    expect_true(all(file.exists(c(qs_file, hash_file, other_file))))
     expect_message(clear_stash(), "Clearing stash")
-    expect_false(any(file.exists(c(rds_file, hash_file))))
+    expect_false(any(file.exists(c(qs_file, hash_file))))
     expect_true(file.exists(other_file))
 })
